package com.persagy.iottransfer.kafka;

import com.alibaba.fastjson.JSONObject;
import com.persagy.iottransfer.communication.entity.Packet;
import com.persagy.iottransfer.communication.entity.PacketEntity;
import com.persagy.iottransfer.server.IotServer;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.kafka.support.Acknowledgment;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @description:
 * @author:lgy
 * @data:2021/8/20 10:10
 */
@Component
@Slf4j
@ConditionalOnProperty(prefix = "iot.type", name = "edge", havingValue = "true", matchIfMissing = false)
public class KafkaConsumerCloud2Edge {

    @KafkaListener(topics = KafkaProducer.TOPIC_COLLECT2EDGE, groupId = "${persagy.group.iot:group_iot}")
    public void topicCollect2Edge(List<String> records, Acknowledgment ack) {
        log.info("persagy.iot.collect2edge收到数据[{}]条，数据为：{}", records.size(), records);
        try {
            for (String record : records) {
                PacketEntity packetEntity = JSONObject.parseObject(record, PacketEntity.class);
                String projectId = packetEntity.getProjectId();
                Packet packet = packetEntity.getContent();
                IotServer.tcpCollectServerManager.AppendToSendByProject(projectId, packet);
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            ack.nack(2000);
            return;
        }
        ack.acknowledge();
    }

    @KafkaListener(topics = KafkaProducer.TOPIC_CONTROL2EDGE, groupId = "${persagy.group.iot:group_iot}")
    public void topicControl2Edge(List<String> records, Acknowledgment ack) {
        log.info("persagy.iot.control2edge收到数据[{}]条，数据为：{}", records.size(), records);
        for (String record : records) {
            PacketEntity packetEntity = JSONObject.parseObject(record, PacketEntity.class);
            String projectId = packetEntity.getProjectId();
            Packet packet = packetEntity.getContent();
            IotServer.tcpControlServerManager.AppendToSendByProject(projectId, packet);
        }
        ack.acknowledge();
    }
}