package com.persagy.iottransfer.kafka;

import com.alibaba.fastjson.JSONObject;
import com.persagy.iottransfer.client.IotClient;
import com.persagy.iottransfer.communication.entity.PacketEntity;
import com.persagy.iottransfer.communication.util.IClientManager;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.kafka.annotation.KafkaListener;
import org.springframework.kafka.support.Acknowledgment;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * @description:
 * @author:lgy
 * @data:2021/8/20 10:10
 */
@Component
@Slf4j
@ConditionalOnProperty(prefix = "iot.type", name = "cloud", havingValue = "true", matchIfMissing = false)
public class KafkaConsumerEdge2Cloud {


    @KafkaListener(topics = KafkaProducer.TOPIC_EDGE2COLLECT, groupId = "${persagy.group.iot:group_iot}")
    public void topicEdge2Collect(List<String> records, Acknowledgment ack) {
        log.info("persagy.iot.edge2collect收到数据[{}]条，数据为：{}", records.size(), records);
        try {
            for (String record : records) {
                PacketEntity packetEntity = JSONObject.parseObject(record, PacketEntity.class);
                IClientManager clientManager = IotClient.CLIENT_PROJECT_2_COLLECT_MANAGER_MAP.get(packetEntity.getProjectId());
                if (clientManager != null) {
                    clientManager.AppendToSend(packetEntity.content);
                }
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            ack.nack(2000);
            return;
        }
        ack.acknowledge();
    }

    @KafkaListener(topics = KafkaProducer.TOPIC_EDGE2CONTROL, groupId = "${persagy.group.iot:group_iot}")
    public void topicEdge2Control(List<String> records, Acknowledgment ack) {
        log.info("persagy.iot.edge2control收到数据[{}]条，数据为：{}", records.size(), records);
        try {
            for (String record : records) {
                PacketEntity packetEntity = JSONObject.parseObject(record, PacketEntity.class);
                IClientManager clientManager = IotClient.CLIENT_PROJECT_2_CONTROL_MANAGER_MAP.get(packetEntity.getProjectId());
                if (clientManager != null) {
                    clientManager.AppendToSend(packetEntity.content);
                }
            }
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        ack.acknowledge();
    }


}